==> kdepim-addons-17.08.0.tar.xz: kdepim-addons-17.08.0/plugins/webengineurlinterceptor/adblock/lib/widgets/adblockpluginurlinterceptorconfiguredialog.h <==
/*
   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef ADBLOCKPLUGINURLINTERCEPTORCONFIGUREDIALOG_H
#define ADBLOCKPLUGINURLINTERCEPTORCONFIGUREDIALOG_H

#include <PimCommon/ConfigurePluginDialog>
#include <QWidget>
#include "adblocklib_export.h"

namespace AdBlock {
class AdblockPluginUrlInterceptorConfigureWidget;
class ADBLOCKLIB_EXPORT AdblockPluginUrlInterceptorConfigureDialog : public PimCommon::ConfigurePluginDialog
{
    Q_OBJECT
public:
    explicit AdblockPluginUrlInterceptorConfigureDialog(QWidget *parent = nullptr);
    ~AdblockPluginUrlInterceptorConfigureDialog();

protected:
    QWidget *createLayout() override;
    void save() override;
    void load() override;
    void reset() override;
    void help() override;
private:
    AdblockPluginUrlInterceptorConfigureWidget *mAdblockConfigureWidget;
};
}
#endif // ADBLOCKPLUGINURLINTERCEPTORCONFIGUREDIALOG_H

==> kdepim-addons-20.07.90.tar.xz: kdepim-addons-20.07.90/plugins/webengineurlinterceptor/adblock/lib/widgets/adblockpluginurlinterceptorconfiguredialog.h <==
/*
   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef ADBLOCKPLUGINURLINTERCEPTORCONFIGUREDIALOG_H
#define ADBLOCKPLUGINURLINTERCEPTORCONFIGUREDIALOG_H

#include <PimCommon/ConfigurePluginDialog>
#include <QWidget>
#include "adblocklib_export.h"

namespace AdBlock {
class AdblockPluginUrlInterceptorConfigureWidget;
class ADBLOCKLIB_EXPORT AdblockPluginUrlInterceptorConfigureDialog : public PimCommon::ConfigurePluginDialog
{
    Q_OBJECT
public:
    explicit AdblockPluginUrlInterceptorConfigureDialog(QWidget *parent = nullptr);
    ~AdblockPluginUrlInterceptorConfigureDialog() override;

protected:
    QWidget *createLayout() override;
    void save() override;
    void load() override;
    void reset() override;
    void help() override;
private:
    AdblockPluginUrlInterceptorConfigureWidget *mAdblockConfigureWidget = nullptr;
};
}
#endif // ADBLOCKPLUGINURLINTERCEPTORCONFIGUREDIALOG_H
